==> haskell-markdown-unlit-0.6.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 markdown-unlit
version:              0.6.0
visibility:           public
id:                   markdown-unlit-0.6.0-KlynjUAsbPqHcmGjb0FZk4
key:                  markdown-unlit-0.6.0-KlynjUAsbPqHcmGjb0FZk4
license:              MIT
copyright:            (c) 2012-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  ae4b4505d9b5fab0af0fdfc37a7467b6
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-markdown-unlit
hs-libraries:         HSmarkdown-unlit-0.6.0-KlynjUAsbPqHcmGjb0FZk4
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-markdown-unlit-0.6.0-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 markdown-unlit
version:              0.6.0
visibility:           public
id:                   markdown-unlit-0.6.0-CLIAhHRjI1sGJSWsfiNQO
key:                  markdown-unlit-0.6.0-CLIAhHRjI1sGJSWsfiNQO
license:              MIT
copyright:            (c) 2012-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  3787fea3d57854ba7e120abd402400ee
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/markdown-unlit-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-markdown-unlit
hs-libraries:         HSmarkdown-unlit-0.6.0-CLIAhHRjI1sGJSWsfiNQO
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
